@@ -1,4 +1,6 @@
 import itertools
+import datetime
+from decimal import Decimal
 
 from sqlglot.helper import while_changing
 from sqlglot.expressions import FALSE, NULL, TRUE
@@ -30,12 +32,12 @@ def simplify(expression):
         node = uniq_sort(node)
         node = absorb_and_eliminate(node)
         exp.replace_children(node, lambda e: _simplify(e, False))
-        node = simplify_equality(node)
         node = simplify_not(node)
         node = flatten(node)
-        node = simplify_conjunctions(node)
+        node = simplify_connectors(node)
         node = remove_compliments(node)
         node.parent = expression.parent
+        node = simplify_literals(node)
         node = simplify_parens(node)
         if root:
             expression.replace(node)
@@ -46,26 +48,6 @@ def simplify(expression):
     return expression
 
 
-def simplify_equality(expression):
-    if isinstance(expression, exp.EQ):
-        left = expression.left
-        right = expression.right
-
-        if NULL in (left, right):
-            return NULL
-        if left == right:
-            return TRUE
-        if (
-            isinstance(left, exp.Literal)
-            and isinstance(right, exp.Literal)
-            and left.is_string
-            and right.is_string
-            and left != right
-        ):
-            return FALSE
-    return expression
-
-
 def simplify_not(expression):
     if isinstance(expression, exp.Not):
         if always_true(expression.this):
@@ -92,7 +74,7 @@ def flatten(expression):
     return expression
 
 
-def simplify_conjunctions(expression):
+def simplify_connectors(expression):
     if isinstance(expression, exp.Connector):
         left = expression.left
         right = expression.right
@@ -213,8 +195,67 @@ def absorb_and_eliminate(expression):
     return expression
 
 
-def is_complement(a, b):
-    return isinstance(b, exp.Not) and b.this == a
+def simplify_literals(expression):
+    if isinstance(expression, exp.Binary):
+        a, b = expression.unnest_operands()
+
+        if isinstance(expression, exp.Is):
+            if isinstance(b, exp.Not):
+                c = b.this
+                not_ = True
+            else:
+                c = b
+                not_ = False
+
+            if c == NULL:
+                if isinstance(a, exp.Literal):
+                    return TRUE if not_ else FALSE
+                if a == NULL:
+                    return FALSE if not_ else TRUE
+        elif NULL in (a, b):
+            return NULL
+
+        if isinstance(expression, exp.EQ) and a == b:
+            return TRUE
+
+        if is_number(a) and is_number(b):
+            a = int(a.name) if a.is_int else Decimal(a.name)
+            b = int(b.name) if b.is_int else Decimal(b.name)
+
+            if isinstance(expression, exp.Add):
+                return exp.Literal.number(a + b)
+            if isinstance(expression, exp.Sub):
+                return exp.Literal.number(a - b)
+            if isinstance(expression, exp.Mul):
+                return exp.Literal.number(a * b)
+            if isinstance(expression, exp.Div):
+                if isinstance(a, int) and isinstance(b, int):
+                    return exp.Literal.number(a // b)
+                return exp.Literal.number(a / b)
+
+            boolean = eval_boolean(expression, a, b)
+
+            if boolean:
+                return boolean
+        elif is_string(a) and is_string(b):
+            boolean = eval_boolean(expression, a, b)
+
+            if boolean:
+                return boolean
+        elif isinstance(a, exp.Cast) and isinstance(b, exp.Interval):
+            a, b = extract_date(a), extract_interval(b)
+            if b:
+                if isinstance(expression, exp.Add):
+                    return date_literal(a + b)
+                if isinstance(expression, exp.Sub):
+                    return date_literal(a - b)
+        elif isinstance(a, exp.Interval) and isinstance(b, exp.Cast):
+            a, b = extract_interval(a), extract_date(b)
+            # you cannot subtract a date from an interval
+            if a and isinstance(expression, exp.Add):
+                return date_literal(a + b)
+
+    return expression
 
 
 def simplify_parens(expression):
@@ -242,3 +283,65 @@ def remove_where_true(expression):
 
 def always_true(expression):
     return expression == TRUE or isinstance(expression, exp.Literal)
+
+
+def is_complement(a, b):
+    return isinstance(b, exp.Not) and b.this == a
+
+
+def is_number(expression):
+    return isinstance(expression, exp.Literal) and not expression.is_string
+
+
+def is_string(expression):
+    return isinstance(expression, exp.Literal) and expression.is_string
+
+
+def eval_boolean(expression, a, b):
+    if isinstance(expression, (exp.EQ, exp.Is)):
+        return boolean_literal(a == b)
+    if isinstance(expression, exp.NEQ):
+        return boolean_literal(a != b)
+    if isinstance(expression, exp.GT):
+        return boolean_literal(a > b)
+    if isinstance(expression, exp.GTE):
+        return boolean_literal(a >= b)
+    if isinstance(expression, exp.LT):
+        return boolean_literal(a < b)
+    if isinstance(expression, exp.LTE):
+        return boolean_literal(a <= b)
+    return None
+
+
+def extract_date(cast):
+    if cast.args["to"].this == exp.DataType.Type.DATE:
+        return datetime.date.fromisoformat(cast.name)
+    return None
+
+
+def extract_interval(interval):
+    try:
+        from dateutil.relativedelta import relativedelta
+    except ModuleNotFoundError:
+        return None
+
+    n = int(interval.name)
+    unit = interval.text("unit").lower()
+
+    if unit == "year":
+        return relativedelta(years=n)
+    if unit == "month":
+        return relativedelta(months=n)
+    if unit == "week":
+        return relativedelta(weeks=n)
+    if unit == "day":
+        return relativedelta(days=n)
+    return None
+
+
+def date_literal(date):
+    return exp.Cast(this=exp.Literal.string(date), to=exp.DataType.build("DATE"))
+
+
+def boolean_literal(condition):
+    return TRUE if condition else FALSE
